@@ -160,7 +160,18 @@ describe 'tempest' do
           )
         end
 
+        it 'installs python-openstackclient package' do
+          is_expected.to contain_package('python-openstackclient').with(
+            :tag => 'openstack'
+          )
+        end
+
         it 'configure tempest config' do
+          is_expected.to contain_tempest_config('auth/admin_domain_name').with(:value => nil)
+          is_expected.to contain_tempest_config('auth/admin_password').with_secret( true )
+          is_expected.to contain_tempest_config('auth/admin_project_name').with(:value => nil)
+          is_expected.to contain_tempest_config('auth/admin_username').with(:value => nil)
+          is_expected.to contain_tempest_config('auth/use_dynamic_credentials').with(:value => nil)
           is_expected.to contain_tempest_config('compute/change_password_available').with(:value => nil)
           is_expected.to contain_tempest_config('compute/flavor_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/flavor_ref_alt').with(:value => nil)
@@ -169,22 +180,16 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('compute/image_ref_alt').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('compute/resize_available').with(:value => nil)
-          is_expected.to contain_tempest_config('compute/allow_tenant_isolation').with(:value => nil)
           is_expected.to contain_tempest_config('compute/build_interval').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/admin_password').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/admin_domain_name').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/admin_password').with_secret( true )
-          is_expected.to contain_tempest_config('identity/admin_tenant_name').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/admin_username').with(:value => nil)
           is_expected.to contain_tempest_config('identity/admin_role').with(:value => nil)
           is_expected.to contain_tempest_config('identity/auth_version').with(:value => 'v2')
           is_expected.to contain_tempest_config('identity/alt_password').with(:value => nil)
           is_expected.to contain_tempest_config('identity/alt_password').with_secret( true )
-          is_expected.to contain_tempest_config('identity/alt_tenant_name').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/alt_project_name').with(:value => nil)
           is_expected.to contain_tempest_config('identity/alt_username').with(:value => nil)
           is_expected.to contain_tempest_config('identity/password').with(:value => nil)
           is_expected.to contain_tempest_config('identity/password').with_secret( true )
-          is_expected.to contain_tempest_config('identity/tenant_name').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/project_name').with(:value => nil)
           is_expected.to contain_tempest_config('identity/uri').with(:value => nil)
           is_expected.to contain_tempest_config('identity/uri_v3').with(:value => nil)
           is_expected.to contain_tempest_config('identity/username').with(:value => nil)
@@ -201,6 +206,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/heat').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ceilometer').with(:value => false)
           is_expected.to contain_tempest_config('service_available/aodh').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/gnocchi').with(:value => false)
           is_expected.to contain_tempest_config('service_available/horizon').with(:value => true)
           is_expected.to contain_tempest_config('service_available/neutron').with(:value => true)
           is_expected.to contain_tempest_config('service_available/nova').with(:value => true)
@@ -214,11 +220,10 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
           is_expected.to contain_tempest_config('oslo_concurrency/lock_path').with(:value => '/var/lib/tempest')
           is_expected.to contain_tempest_config('DEFAULT/debug').with(:value => false)
-          is_expected.to contain_tempest_config('DEFAULT/verbose').with(:value => false)
+          is_expected.to contain_tempest_config('DEFAULT/log_file').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('DEFAULT/use_stderr').with(:value => true)
           is_expected.to contain_tempest_config('DEFAULT/use_syslog').with(:value => false)
-          is_expected.to contain_tempest_config('DEFAULT/log_file').with(:value => nil)
-          is_expected.to contain_tempest_config('DEFAULT/logging_context_format_string').with(:value => nil)
+          is_expected.to contain_tempest_config('DEFAULT/logging_context_format_string').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('scenario/img_dir').with(:value => '/var/lib/tempest')
           is_expected.to contain_tempest_config('scenario/img_file').with(:value => 'cirros-0.3.4-x86_64-disk.img')
           is_expected.to contain_tempest_config('service_broker/run_service_broker_tests').with(:value => false)
@@ -272,59 +277,60 @@ describe 'tempest' do
           :aodh_available        => true }
       end
 
-      describe "should install keystone tests package" do
+      describe "should install aodh tests package" do
         it { expect { is_expected.to contain_package('python-aodh-tests') } }
       end
     end
-  end
 
-
-  context 'on Debian platforms' do
-    let :facts do
-      { :osfamily     => 'Debian' }
-    end
-
-    let :platform_params do
-      { :dev_packages => ['python-dev',
-                          'libxslt1-dev',
-                          'libxml2-dev',
-                          'libssl-dev',
-                          'libffi-dev',
-                          'patch',
-                          'gcc' ] }
-    end
-
-    it_behaves_like 'tempest'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      { :osfamily               => 'RedHat',
-        :operatingsystemrelease => '7' }
-    end
-
-    let :platform_params do
-      { :dev_packages => ['python-devel',
-                          'libxslt-devel',
-                          'libxml2-devel',
-                          'openssl-devel',
-                          'libffi-devel',
-                          'patch',
-                          'gcc' ] }
-    end
-
-    it_behaves_like 'tempest'
-    it_behaves_like 'tempest with plugins packages'
-  end
-
-  context 'unsupported operating system' do
-    describe 'tempest class without any parameters on Solaris/Nexenta' do
-      let :facts do
-        { :osfamily => 'Solaris',
-        :operatingsystem => 'Nexenta' }
+    context 'with when managing tests packages for neutron (optional service)' do
+      let :params do
+        { :manage_tests_packages => true,
+          :neutron_available        => true }
       end
 
-      it { expect { is_expected.to contain_package('tempest') }.to raise_error(Puppet::Error, /Unsupported osfamily: Solaris operatingsystem: Nexenta/) }
+      describe "should install neutron and *aas tests packages" do
+        it { expect { is_expected.to contain_package('python-neutron-tests') } }
+        it { expect { is_expected.to contain_package('python-neutron-fwaas-tests') } }
+        it { expect { is_expected.to contain_package('python-neutron-lbaas-tests') } }
+        it { expect { is_expected.to contain_package('python-neutron-vpnaas-tests') } }
+      end
+    end
+  end
+
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts({
+          :concat_basedir => '/var/lib/puppet/concat',
+          :processorcount => 2
+        }))
+      end
+      let(:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :dev_packages => ['python-dev',
+                              'libxslt1-dev',
+                              'libxml2-dev',
+                              'libssl-dev',
+                              'libffi-dev',
+                              'patch',
+                              'gcc',
+                              'python-virtualenv' ] }
+        when 'RedHat'
+          { :dev_packages => ['python-devel',
+                              'libxslt-devel',
+                              'libxml2-devel',
+                              'openssl-devel',
+                              'libffi-devel',
+                              'patch',
+                              'gcc'] }
+        end
+      end
+
+      it_behaves_like 'tempest'
+      it_behaves_like 'tempest with plugins packages'
     end
   end
 end
